@@ -386,6 +386,12 @@ parse_dot1x_auth(GKeyFile* kf, NetplanAuthenticationSettings* auth)
             auth->eap_method = NETPLAN_AUTH_EAP_PEAP;
         } else if (g_strcmp0(first_method, "ttls") == 0) {
             auth->eap_method = NETPLAN_AUTH_EAP_TTLS;
+        } else if (g_strcmp0(first_method, "leap") == 0) {
+            auth->eap_method = NETPLAN_AUTH_EAP_LEAP;
+        } else if (g_strcmp0(first_method, "pwd") == 0) {
+            auth->eap_method = NETPLAN_AUTH_EAP_PWD;
+        } else {
+            auth->eap_method = NETPLAN_AUTH_EAP_UNKNOWN;
         }
 
         /* If "method" (which is a list separated by ";") has more than one value,
@@ -394,8 +400,11 @@ parse_dot1x_auth(GKeyFile* kf, NetplanAuthenticationSettings* auth)
          * but Netplan accepts only one.
          *
          * TODO: eap_method needs to be fixed to store multiple methods.
+         *
+         * If at this point the eap_method is still UNKNOWN we also keep the property because
+         * it's probably a setting we still don't support.
          */
-        if (split[1] == NULL || !g_strcmp0(split[1], ""))
+        if (auth->eap_method != NETPLAN_AUTH_EAP_UNKNOWN && (split[1] == NULL || !g_strcmp0(split[1], "")))
             _kf_clear_key(kf, "802-1x", "eap");
 
         g_strfreev(split);
@@ -403,8 +412,7 @@ parse_dot1x_auth(GKeyFile* kf, NetplanAuthenticationSettings* auth)
 
     keyfile_handle_generic_str(kf, "802-1x", "identity", &auth->identity);
     keyfile_handle_generic_str(kf, "802-1x", "anonymous-identity", &auth->anonymous_identity);
-    if (!auth->password)
-        keyfile_handle_generic_str(kf, "802-1x", "password", &auth->password);
+    keyfile_handle_generic_str(kf, "802-1x", "password", &auth->password);
     keyfile_handle_generic_str(kf, "802-1x", "ca-cert", &auth->ca_certificate);
     keyfile_handle_generic_str(kf, "802-1x", "client-cert", &auth->client_certificate);
     keyfile_handle_generic_str(kf, "802-1x", "private-key", &auth->client_key);
@@ -552,7 +560,11 @@ parse_tunnels(GKeyFile* kf, NetplanNetDefinition* nd)
                 }
 
                 /* Handle endpoint */
-                wireguard_peer->endpoint = g_key_file_get_string(kf, group, "endpoint", NULL);
+                gchar* endpoint = g_key_file_get_string(kf, group, "endpoint", NULL);
+                if (endpoint && g_strcmp0(endpoint, "")) {
+                    /* Only set the endpoint if it's not NULL nor an empty string */
+                    wireguard_peer->endpoint = endpoint;
+                }
                 _kf_clear_key(kf, group, "endpoint");
 
                 g_array_append_val(nd->wireguard_peers, wireguard_peer);
@@ -609,6 +621,7 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     g_autofree gchar* netdef_id = NULL;
     ssize_t netdef_id_size = 0;
     gchar *tmp_str = NULL;
+    gint pmf = 0;
     NetplanNetDefinition* nd = NULL;
     NetplanWifiAccessPoint* ap = NULL;
     g_autoptr(GKeyFile) kf = g_key_file_new();
@@ -970,6 +983,10 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
             ap->auth.key_management = NETPLAN_AUTH_KEY_MANAGEMENT_WPA_EAP;
             ap->has_auth = TRUE;
             _kf_clear_key(kf, "wifi-security", "key-mgmt");
+        } else if (tmp_str && g_strcmp0(tmp_str, "wpa-eap-suite-b-192") == 0) {
+            ap->auth.key_management = NETPLAN_AUTH_KEY_MANAGEMENT_WPA_EAPSUITE_B_192;
+            ap->has_auth = TRUE;
+            _kf_clear_key(kf, "wifi-security", "key-mgmt");
         } else if (tmp_str && g_strcmp0(tmp_str, "sae") == 0) {
             ap->auth.key_management = NETPLAN_AUTH_KEY_MANAGEMENT_WPA_SAE;
             ap->has_auth = TRUE;
@@ -981,8 +998,28 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
         }
         g_free(tmp_str);
 
-        keyfile_handle_generic_str(kf, "wifi-security", "psk", &ap->auth.password);
-        if (ap->auth.password)
+        pmf = g_key_file_get_integer(kf, "wifi-security", "pmf", NULL);
+        switch (pmf) {
+            case 2:
+                ap->auth.pmf_mode = NETPLAN_AUTH_PMF_MODE_OPTIONAL;
+                _kf_clear_key(kf, "wifi-security", "pmf");
+                /* If pmf is set to 2 (optional) and the key management is EAP
+                 * we set it to EAPSHA256 so the correct method is emitted in the YAML
+                 */
+                if (ap->auth.key_management == NETPLAN_AUTH_KEY_MANAGEMENT_WPA_EAP)
+                    ap->auth.key_management = NETPLAN_AUTH_KEY_MANAGEMENT_WPA_EAPSHA256;
+                break;
+
+            case 3:
+                ap->auth.pmf_mode = NETPLAN_AUTH_PMF_MODE_REQUIRED;
+                _kf_clear_key(kf, "wifi-security", "pmf");
+                break;
+
+            default: break;
+        }
+
+        keyfile_handle_generic_str(kf, "wifi-security", "psk", &ap->auth.psk);
+        if (ap->auth.psk)
             ap->has_auth = TRUE;
 
         parse_dot1x_auth(kf, &ap->auth);
