@@ -89,7 +89,7 @@ class TestConfigArgs(TestBase):
 
         p = subprocess.Popen([exe_generate, '--root-dir', self.workdir.name, '--help'],
                              stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                             universal_newlines=True)
+                             text=True)
         (out, err) = p.communicate()
         self.assertEqual(err, '')
         self.assertEqual(p.returncode, 0)
@@ -99,7 +99,7 @@ class TestConfigArgs(TestBase):
     def test_unknown_cli_args(self):
         p = subprocess.Popen([exe_generate, '--foo'],
                              stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                             universal_newlines=True)
+                             text=True)
         (out, err) = p.communicate()
         self.assertIn('nknown option --foo', err)
         self.assertNotEqual(p.returncode, 0)
